Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(753)

Unified Diff: base/win/win_util.cc

Issue 10643004: Merge 143290 - Replace all spaces by '_' in the AppUserModelId (Closed) Base URL: svn://svn.chromium.org/chrome/branches/1180/src/
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/installer/util/shell_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/win/win_util.cc
===================================================================
--- base/win/win_util.cc (revision 143429)
+++ base/win/win_util.cc (working copy)
@@ -180,10 +180,10 @@
bool SetAppIdForPropertyStore(IPropertyStore* property_store,
const wchar_t* app_id) {
// App id should be less than 128 chars and contain no space. And recommended
// format is CompanyName.ProductName[.SubProduct.ProductNumber].
// See http://msdn.microsoft.com/en-us/library/dd378459%28VS.85%29.aspx
- DCHECK(lstrlen(app_id) < 128 && wcschr(app_id, L' ') == NULL);
+ DCHECK(lstrlen(app_id) < 64 && wcschr(app_id, L' ') == NULL);
return SetStringValueForPropertyStore(property_store,
PKEY_AppUserModel_ID,
« no previous file with comments | « no previous file | chrome/installer/util/shell_util.cc » ('j') | no next file with comments »
@@ -180,10 +180,10 @@
bool SetAppIdForPropertyStore(IPropertyStore* property_store,
const wchar_t* app_id) {
- // App id should be less than 128 chars and contain no space. And recommended
+ // App id should be less than 64 chars and contain no space. And recommended
// format is CompanyName.ProductName[.SubProduct.ProductNumber].
// See http://msdn.microsoft.com/en-us/library/dd378459%28VS.85%29.aspx

Powered by Google App Engine
This is Rietveld 408576698